@@ -1,5 +1,7 @@
 """
-Main interface for shield service client paginators.
+Type annotations for shield service client paginators.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/paginators.html)
 
 Usage::
 
@@ -34,7 +36,7 @@ __all__ = ("ListAttacksPaginator", "ListProtectionsPaginator")
 
 class ListAttacksPaginator(Boto3Paginator):
     """
-    [Paginator.ListAttacks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/shield.html#Shield.Paginator.ListAttacks)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/shield.html#Shield.Paginator.ListAttacks)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/paginators.html#listattackspaginator)
     """
 
     def paginate(
@@ -45,18 +47,20 @@ class ListAttacksPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListAttacksResponseTypeDef]:
         """
-        [ListAttacks.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/shield.html#Shield.Paginator.ListAttacks.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/shield.html#Shield.Paginator.ListAttacks.paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/paginators.html#listattackspaginator)
         """
 
 
 class ListProtectionsPaginator(Boto3Paginator):
     """
-    [Paginator.ListProtections documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/shield.html#Shield.Paginator.ListProtections)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/shield.html#Shield.Paginator.ListProtections)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/paginators.html#listprotectionspaginator)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListProtectionsResponseTypeDef]:
         """
-        [ListProtections.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/shield.html#Shield.Paginator.ListProtections.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.63/reference/services/shield.html#Shield.Paginator.ListProtections.paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/paginators.html#listprotectionspaginator)
         """
